==> zio-aws-apigatewayv2_2.12-5.17.267.7-sources.jar: zio/aws/apigatewayv2/model/GetAuthorizerRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetAuthorizerRequest(apiId: __string, authorizerId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest = {
    import GetAuthorizerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .authorizerId(authorizerId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetAuthorizerRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetAuthorizerRequest.wrap(buildAwsValue())
}
object GetAuthorizerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetAuthorizerRequest =
      zio.aws.apigatewayv2.model.GetAuthorizerRequest(apiId, authorizerId)
    def apiId: __string
    def authorizerId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getAuthorizerId: ZIO[Any, Nothing, __string] = ZIO.succeed(authorizerId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
  ) extends zio.aws.apigatewayv2.model.GetAuthorizerRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val authorizerId: __string = impl.authorizerId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
  ): zio.aws.apigatewayv2.model.GetAuthorizerRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_2.13-5.17.121.2-sources.jar: zio/aws/apigatewayv2/model/GetAuthorizerRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetAuthorizerRequest(apiId: __string, authorizerId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest = {
    import GetAuthorizerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .authorizerId(__string.unwrap(authorizerId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetAuthorizerRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetAuthorizerRequest.wrap(buildAwsValue())
}
object GetAuthorizerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetAuthorizerRequest =
      zio.aws.apigatewayv2.model.GetAuthorizerRequest(apiId, authorizerId)
    def apiId: __string
    def authorizerId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getAuthorizerId: ZIO[Any, Nothing, __string] = ZIO.succeed(authorizerId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
  ) extends zio.aws.apigatewayv2.model.GetAuthorizerRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val authorizerId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.authorizerId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetAuthorizerRequest
  ): zio.aws.apigatewayv2.model.GetAuthorizerRequest.ReadOnly = new Wrapper(
    impl
  )
}
